@@ -1,3 +1,4 @@
+#include "wayfire/util/duration.hpp"
 #define DOCTEST_CONFIG_IMPLEMENT_WITH_MAIN
 #include <doctest/doctest.h>
 
@@ -400,8 +401,13 @@ TEST_CASE("wf::activatorbinding_t")
         0, 1);
 
     CHECK(!from_string<activatorbinding_t>("<alt> KEY_K || <alt> KEY_U"));
-    CHECK(!from_string<activatorbinding_t>("<alt> KEY_K | thrash"));
     CHECK(!from_string<activatorbinding_t>("<alt> KEY_K |"));
+
+    auto with_ext = from_string<activatorbinding_t>("<alt> KEY_T | thrash");
+    CHECK(with_ext.has_value() == true);
+    CHECK(with_ext->get_extensions().size() == 1);
+    CHECK(with_ext->get_extensions().front() == "thrash");
+    CHECK(with_ext->has_match(kb1));
 }
 
 TEST_CASE("wf::output_config::mode_t")
@@ -499,3 +505,40 @@ TEST_CASE("wf::output_config::position_t")
     CHECK(!from_string<pt>("129 129"));
     CHECK(!from_string<pt>("129,"));
 }
+
+TEST_CASE("wf::animation::animation_description_t")
+{
+    using adt = wf::animation_description_t;
+    CHECK(!from_string<adt>("test"));
+    CHECK(!from_string<adt>("100ss"));
+    CHECK(!from_string<adt>("100 ms invalideasing"));
+    CHECK(!from_string<adt>("100 ms linear trailing"));
+
+    adt circle100 = {
+        .length_ms = 100,
+        .easing    = wf::animation::smoothing::circle,
+        .easing_name = "circle",
+    };
+    std::string circle100_str   = "100";
+    std::string circle100_str_2 = "100 ms";
+
+    adt linear8s = {
+        .length_ms = 8500,
+        .easing    = wf::animation::smoothing::linear,
+        .easing_name = "linear",
+    };
+    std::string linear8s_str = "8.5s linear";
+
+    adt sigmoid250ms = {
+        .length_ms = 250,
+        .easing    = wf::animation::smoothing::sigmoid,
+        .easing_name = "sigmoid",
+    };
+    std::string sigmoid250ms_str = "250ms sigmoid";
+
+    CHECK(from_string<adt>(circle100_str) == circle100);
+    CHECK(from_string<adt>(circle100_str_2) == circle100);
+    CHECK(from_string<adt>(linear8s_str) == linear8s);
+    CHECK(from_string<adt>(sigmoid250ms_str) == sigmoid250ms);
+    CHECK(to_string<adt>(sigmoid250ms) == sigmoid250ms_str);
+}
